==> blesta-5.10.2.zip: blesta/language/el_gr/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Εναλλαγή πλοήγησης';
$lang['AppController.sreader.dropdown'] = 'Εναλλαγή Dropdown';
$lang['AppController.graphs.label.total'] = 'Σύνολο';
$lang['AppController.graphs.control_label.grouped'] = 'Ομαδοποιημένα';
$lang['AppController.graphs.control_label.expanded'] = 'Διευρυμένο';
$lang['AppController.graphs.control_label.stream'] = 'Ρεύμα';
$lang['AppController.graphs.control_label.stacked'] = 'Στοίβαγμα';
$lang['AppController.dates.monthabbr_dec'] = 'Δεκέμβριος';
$lang['AppController.dates.monthabbr_nov'] = 'Νοέμβριος';
$lang['AppController.dates.monthabbr_oct'] = 'Οκτώβριος';
$lang['AppController.dates.monthabbr_sep'] = 'Σεπτέμβριος';
$lang['AppController.dates.monthabbr_aug'] = 'Αύγουστος';
$lang['AppController.dates.monthabbr_jul'] = 'Ιουλ';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Μάιος';
$lang['AppController.dates.monthabbr_apr'] = 'Απρίλιος';
$lang['AppController.dates.monthabbr_mar'] = 'Μαρ';
$lang['AppController.dates.monthabbr_feb'] = 'Φεβρουάριος';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Δεκέμβριος';
$lang['AppController.dates.month_nov'] = 'Νοέμβριος';
$lang['AppController.dates.month_oct'] = 'Οκτώβριος';
$lang['AppController.dates.month_sep'] = 'Σεπτέμβριος';
$lang['AppController.dates.month_aug'] = 'Αύγουστος';
$lang['AppController.dates.month_jul'] = 'Ιούλιος';
$lang['AppController.dates.month_jun'] = 'Ιούνιος';
$lang['AppController.dates.month_may'] = 'Μάιος';
$lang['AppController.dates.month_apr'] = 'Απρίλιος';
$lang['AppController.dates.month_mar'] = 'Μάρτιος';
$lang['AppController.dates.month_feb'] = 'Φεβρουάριος';
$lang['AppController.dates.month_jan'] = 'Ιανουάριος';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Παρ';
$lang['AppController.dates.dayabbr_thur'] = 'Πέμ';
$lang['AppController.dates.dayabbr_wed'] = 'Τετ';
$lang['AppController.dates.dayabbr_tue'] = 'Τρίτη';
$lang['AppController.dates.dayabbr_mon'] = 'Δευτέρα';
$lang['AppController.dates.dayabbr_sun'] = 'Ήλιος';
$lang['AppController.dates.day_sat'] = 'Σάββατο';
$lang['AppController.dates.day_fri'] = 'Παρασκευή';
$lang['AppController.dates.day_thu'] = 'Πέμπτη';
$lang['AppController.dates.day_wed'] = 'Τετάρτη';
$lang['AppController.dates.day_tue'] = 'Τρίτη';
$lang['AppController.dates.day_mon'] = 'Δευτέρα';
$lang['AppController.dates.day_sun'] = 'Κυριακή';
$lang['AppController.client_structure.text_managers'] = 'Διευθυντές';
$lang['AppController.client_structure.text_contacts'] = 'Επαφές';
$lang['AppController.client_structure.text_accounts'] = 'Λογαριασμοί πληρωμών';
$lang['AppController.client_structure.text_emails'] = 'Ιστορικό email';
$lang['AppController.client_structure.text_update_account'] = 'Διαχείριση λογαριασμού';
$lang['AppController.client_structure.text_login'] = 'Σύνδεση';
$lang['AppController.client_structure.text_logout'] = 'Αποσύνδεση';
$lang['AppController.client_structure.text_return_to_portal'] = 'Επιστροφή στην Πύλη';
$lang['AppController.client_structure.default_title'] = 'Ο λογαριασμός μου';
$lang['AppController.client_structure.staff_as_client_note'] = 'Επιστροφή στην Πύλη Προσωπικού';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Η λειτουργία συντήρησης είναι ενεργοποιημένη και οι πελάτες δεν μπορούν να συνδεθούν. Κάντε κλικ εδώ για να αλλάξετε.';
$lang['AppController.structure.text_logout'] = 'Αποσύνδεση';
$lang['AppController.structure.text_settings'] = 'Ρυθμίσεις';
$lang['AppController.structure.text_myinfo'] = 'Οι πληροφορίες μου';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Επιστροφή στο λογαριασμό μου';
$lang['AppController.banners.client_manager'] = 'Αυτή τη στιγμή διαχειρίζεστε έναν λογαριασμό που σας έχει προσκαλέσει να τον διαχειριστείτε.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Παρακαλώ επιβεβαιώστε';
$lang['AppController.modal.text_close'] = 'Κλείστε το';
$lang['AppController.select.please'] = '-- Παρακαλώ επιλέξτε --';
$lang['AppController.!success.license_key_updated'] = 'Το κλειδί άδειας χρήσης ενημερώθηκε με επιτυχία. Παρακαλώ συνδεθείτε.';
$lang['AppController.!success.license_updated'] = 'Η άδειά σας επικυρώθηκε επιτυχώς. Παρακαλώ συνδεθείτε.';
$lang['AppController.!error.invalid_csrf'] = 'Το σύμβολο της φόρμας είναι άκυρο.';
$lang['AppController.!error.unauthorized_access'] = 'Δεν είστε εξουσιοδοτημένοι να έχετε πρόσβαση σε αυτόν τον πόρο';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Αφήστε αρχεία εδώ για να τα ανεβάσετε ή κάντε κλικ για να επιλέξετε αρχεία';

==> blesta-5.11.4.zip: blesta/language/el_gr/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Εναλλαγή πλοήγησης';
$lang['AppController.sreader.dropdown'] = 'Εναλλαγή Dropdown';
$lang['AppController.graphs.label.total'] = 'Σύνολο';
$lang['AppController.graphs.control_label.grouped'] = 'Ομαδοποιημένα';
$lang['AppController.graphs.control_label.expanded'] = 'Διευρυμένο';
$lang['AppController.graphs.control_label.stream'] = 'Ρεύμα';
$lang['AppController.graphs.control_label.stacked'] = 'Στοίβαγμα';
$lang['AppController.dates.monthabbr_dec'] = 'Δεκέμβριος';
$lang['AppController.dates.monthabbr_nov'] = 'Νοέμβριος';
$lang['AppController.dates.monthabbr_oct'] = 'Οκτώβριος';
$lang['AppController.dates.monthabbr_sep'] = 'Σεπτέμβριος';
$lang['AppController.dates.monthabbr_aug'] = 'Αύγουστος';
$lang['AppController.dates.monthabbr_jul'] = 'Ιουλ';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Μάιος';
$lang['AppController.dates.monthabbr_apr'] = 'Απρίλιος';
$lang['AppController.dates.monthabbr_mar'] = 'Μαρ';
$lang['AppController.dates.monthabbr_feb'] = 'Φεβρουάριος';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Δεκέμβριος';
$lang['AppController.dates.month_nov'] = 'Νοέμβριος';
$lang['AppController.dates.month_oct'] = 'Οκτώβριος';
$lang['AppController.dates.month_sep'] = 'Σεπτέμβριος';
$lang['AppController.dates.month_aug'] = 'Αύγουστος';
$lang['AppController.dates.month_jul'] = 'Ιούλιος';
$lang['AppController.dates.month_jun'] = 'Ιούνιος';
$lang['AppController.dates.month_may'] = 'Μάιος';
$lang['AppController.dates.month_apr'] = 'Απρίλιος';
$lang['AppController.dates.month_mar'] = 'Μάρτιος';
$lang['AppController.dates.month_feb'] = 'Φεβρουάριος';
$lang['AppController.dates.month_jan'] = 'Ιανουάριος';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Παρ';
$lang['AppController.dates.dayabbr_thur'] = 'Πέμ';
$lang['AppController.dates.dayabbr_wed'] = 'Τετ';
$lang['AppController.dates.dayabbr_tue'] = 'Τρίτη';
$lang['AppController.dates.dayabbr_mon'] = 'Δευτέρα';
$lang['AppController.dates.dayabbr_sun'] = 'Ήλιος';
$lang['AppController.dates.day_sat'] = 'Σάββατο';
$lang['AppController.dates.day_fri'] = 'Παρασκευή';
$lang['AppController.dates.day_thu'] = 'Πέμπτη';
$lang['AppController.dates.day_wed'] = 'Τετάρτη';
$lang['AppController.dates.day_tue'] = 'Τρίτη';
$lang['AppController.dates.day_mon'] = 'Δευτέρα';
$lang['AppController.dates.day_sun'] = 'Κυριακή';
$lang['AppController.client_structure.text_managers'] = 'Διευθυντές';
$lang['AppController.client_structure.text_contacts'] = 'Επαφές';
$lang['AppController.client_structure.text_accounts'] = 'Λογαριασμοί πληρωμών';
$lang['AppController.client_structure.text_emails'] = 'Ιστορικό email';
$lang['AppController.client_structure.text_update_account'] = 'Διαχείριση λογαριασμού';
$lang['AppController.client_structure.text_login'] = 'Σύνδεση';
$lang['AppController.client_structure.text_logout'] = 'Αποσύνδεση';
$lang['AppController.client_structure.text_return_to_portal'] = 'Επιστροφή στην Πύλη';
$lang['AppController.client_structure.default_title'] = 'Ο λογαριασμός μου';
$lang['AppController.client_structure.staff_as_client_note'] = 'Επιστροφή στην Πύλη Προσωπικού';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Η λειτουργία συντήρησης είναι ενεργοποιημένη και οι πελάτες δεν μπορούν να συνδεθούν. Κάντε κλικ εδώ για να αλλάξετε.';
$lang['AppController.structure.text_logout'] = 'Αποσύνδεση';
$lang['AppController.structure.text_settings'] = 'Ρυθμίσεις';
$lang['AppController.structure.text_myinfo'] = 'Οι πληροφορίες μου';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Επιστροφή στο λογαριασμό μου';
$lang['AppController.banners.client_manager'] = 'Αυτή τη στιγμή διαχειρίζεστε έναν λογαριασμό που σας έχει προσκαλέσει να τον διαχειριστείτε.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Παρακαλώ επιβεβαιώστε';
$lang['AppController.modal.text_close'] = 'Κλείστε το';
$lang['AppController.select.please'] = '-- Παρακαλώ επιλέξτε --';
$lang['AppController.!success.license_key_updated'] = 'Το κλειδί άδειας χρήσης ενημερώθηκε με επιτυχία. Παρακαλώ συνδεθείτε.';
$lang['AppController.!success.license_updated'] = 'Η άδειά σας επικυρώθηκε επιτυχώς. Παρακαλώ συνδεθείτε.';
$lang['AppController.!error.invalid_csrf'] = 'Το σύμβολο της φόρμας είναι άκυρο.';
$lang['AppController.!error.unauthorized_access'] = 'Δεν είστε εξουσιοδοτημένοι να έχετε πρόσβαση σε αυτόν τον πόρο';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Αφήστε αρχεία εδώ για να τα ανεβάσετε ή κάντε κλικ για να επιλέξετε αρχεία';
$lang['AppController.!error.client_unauthorized_access'] = 'Δεν έχετε δικαίωμα πρόσβασης σε αυτόν τον πόρο, παρακαλούμε επικοινωνήστε με τον κύριο κάτοχο του λογαριασμού για να ζητήσετε πρόσβαση.';
